@@ -29,7 +29,7 @@ app.register_blueprint(api)
 requests.post(
     'https://{fqdn}/registry'.format(fqdn=APIGW),
     json={
-        'service': 'fup-services',
+        'service': 'fup',
         'address': ADDRESS,
         'service_code': SERVICE_CODE,
         'host': HOSTNAME,
