@@ -5,10 +5,13 @@ from datetime import datetime, timedelta
 from email.mime.multipart import MIMEMultipart
 from email.mime.base import MIMEBase
 from email.mime.text import MIMEText
+# from jinja2 import Template
 from multiprocessing import Pool
 
 from .. import core
-from ..consts import CONFIG, REDIS_DB
+from ..consts import CONFIG
+# from ..consts import RAPPORT_HTML
+from ..consts import REDIS_DB
 from ..customer import Customer
 from ..product import Product
 from ..product_gp import Product_GP
@@ -63,10 +66,9 @@ def notify():
 
 
 @cmd.command()
-@click.option('--append-details', is_flag=True, default=False)
 @click.option('--for-real', is_flag=True, default=False)
 @click.option('--send-mail', is_flag=True, default=False)
-def apply(append_details, for_real, send_mail):
+def apply(for_real, send_mail):
     """Appliquer les politiques de FUP pour tous les clients Business"""
     result = {}
     products = Product.all()
@@ -76,6 +78,21 @@ def apply(append_details, for_real, send_mail):
             result[product.name] = policies
     if result:
         message = ''
+        dataset_statistics = tablib.Dataset()
+        dataset_statistics.headers = [
+            'product',
+            'fup_in',
+            'fup_out'
+            ]
+        dataset_synthesis = tablib.Dataset()
+        dataset_synthesis.headers = [
+            'policy_name',
+            'product',
+            'false',
+            'true',
+            'total',
+            'true/total'
+            ]
         dataset = tablib.Dataset()
         dataset.headers = [
             'product',
@@ -99,6 +116,10 @@ def apply(append_details, for_real, send_mail):
                         data_limit=policy['data_limit']
                         )
                 foo = ''
+                number_fup_in = 0
+                number_fup_out = 0
+                fup_true = 0
+                total_client = len(policy['customers'])
                 for customer, data in policy['customers'].items():
                     customer_policies_status = Customer(customer).fup_status
                     policy_status = False
@@ -115,19 +136,23 @@ def apply(append_details, for_real, send_mail):
                     dataset.append(
                         [
                             product,
-                            policy['data_limit'],
+                            str(policy['data_limit']).replace('.', ','),
                             policy['name'],
                             customer,
-                            data['octets_in'],
-                            data['octets_out'],
-                            data['total'],
+                            str(data['octets_in']).replace('.', ','),
+                            str(data['octets_out']).replace('.', ','),
+                            str(data['total']).replace('.', ','),
                             policy_status
                             ]
                         )
+                    if policy_status is True:
+                        fup_true += 1
                     if data.get('fup_in'):
+                        number_fup_in = number_fup_in + 1
                         status = 'fup_in'
                     elif data.get('fup_out'):
                         status = 'fup_out'
+                        number_fup_out = number_fup_out + 1
                     else:
                         status = None
                     if status:
@@ -142,13 +167,43 @@ def apply(append_details, for_real, send_mail):
                     message += foo
                 else:
                     message += "Aucun client à FUPer\n"
+                fup_false = total_client - fup_true
+                pourcentage_fup = fup_true * 100 / total_client
+                pourcentage_fup = round(pourcentage_fup)
+                pourcentage_fup = '{}%'.format(pourcentage_fup)
+            dataset_statistics.append(
+                [
+                    product,
+                    number_fup_in,
+                    number_fup_out
+                    ]
+                )
+            dataset_synthesis.append(
+                [
+                    policy['name'],
+                    product,
+                    fup_false,
+                    fup_true,
+                    total_client,
+                    pourcentage_fup
+                    ]
+                )
             message += '\n\n\n'
+        message += str(dataset_statistics)
+        message += '\n\n\n'
+        message += str(dataset_synthesis)
+        # message_html = Template(RAPPORT_HTML).render(
+        #     date=datetime.now().date().strftime('%d/%m/%Y'),
+        #     products=products,
+        #     result=result
+        #     )
         click.echo(message)
         with open('/tmp/details.csv', 'w') as f:
-            f.write(dataset.export('csv'))
+            f.write(dataset.export('csv', delimiter=';'))
         if send_mail:
             recipients = CONFIG['ALERT']['to']
-            content = MIMEText(message, 'plain', 'utf-8')
+            content_text = MIMEText(message, 'plain', 'utf-8')
+            # content_html = MIMEText(message_html, 'html', 'utf-8')
             attachment = MIMEBase('text', 'csv')
             fp = open('/tmp/details.csv', 'rb')
             attachment.set_payload(fp.read())
@@ -158,12 +213,16 @@ def apply(append_details, for_real, send_mail):
                 'attachment',
                 filename='details.csv'
                 )
+
             msg = MIMEMultipart()
             msg['Subject'] = CONFIG['ALERT']['subject']
             msg['From'] = CONFIG['ALERT']['from']
             msg['To'] = recipients
+            # msg_body = MIMEMultipart('alternative')
             msg.attach(attachment)
-            msg.attach(content)
+            # msg.attach(msg_body)
+            # msg.attach(content_html)
+            msg.attach(content_text)
             s = smtplib.SMTP('localhost')
             s.sendmail(
                 CONFIG['ALERT']['from'],
