@@ -236,6 +236,7 @@ class Customer(object):
         """Suivant la politique de bon usage du produit réorganiser les cdrs"""
         result = []
         for policy_name, policy in self.product.policies.items():
+            sources = {}
             info = {
                 'data_limit': policy['data_limit'],
                 'interval': policy['interval'],
@@ -277,20 +278,61 @@ class Customer(object):
                                 )
                         if (in_times and in_days):
                             data.append(i)
-                octets_in = sum([i['octets_in'] for i in data])
-                octets_out = sum([i['octets_out'] for i in data])
-                total = octets_in + octets_out
-                info['total'] += total
-                info['octets_in'] += octets_in
-                info['octets_out'] += octets_out
+                data = sorted(data, key=lambda x: x['source'])
+                day_octets_in = sum(
+                    [
+                        i['octets_in'] for i in data
+                        if i['source'] != 'national'
+                        ]
+                    )
+                day_octets_out = sum(
+                    [
+                        i['octets_out'] for i in data
+                        if i['source'] != 'national'
+                        ]
+                    )
+                day_total = day_octets_in + day_octets_out
+                data = groupby(data, key=lambda x: x['source'])
+                day_details = []
+                for source, element in data:
+                    if source not in sources:
+                        sources[source] = {'octets_in': 0, 'octets_out': 0}
+                    element = list(element)
+                    source_day_octets_in = sum(
+                        [i['octets_in'] for i in element]
+                        )
+                    source_day_octets_out = sum(
+                        [i['octets_out'] for i in element]
+                        )
+                    sources[source]['octets_in'] += source_day_octets_in
+                    sources[source]['octets_out'] += source_day_octets_out
+                    day_details.append(
+                        {
+                            'source': source,
+                            'octets_in': source_day_octets_in,
+                            'octets_out': source_day_octets_out
+                            }
+                        )
+                info['total'] += day_total
+                info['octets_in'] += day_octets_in
+                info['octets_out'] += day_octets_out
                 info['details'].append(
                     {
                         'date': day,
-                        'octets_in': octets_in,
-                        'octets_out': octets_out,
-                        'total': total
+                        'octets_in': day_octets_in,
+                        'octets_out': day_octets_out,
+                        'total': day_total,
+                        'details': day_details
                         }
                     )
+            info['sources'] = [
+                {
+                    'source': source,
+                    'octets_in': bar['octets_in'],
+                    'octets_out': bar['octets_out']
+                    }
+                for source, bar in sources.items()
+                ]
             result.append(info)
         return result
 
